#
# spec file for package tpm2-pkcs11
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver  0
%define pythons python3
Name:           tpm2-pkcs11
Version:        1.9.0
Release:        2.3
Summary:        A PKCS#11 interface for TPM2 hardware
License:        BSD-2-Clause
Group:          Productivity/Security
URL:            https://github.com/tpm2-software/tpm2-pkcs11
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  autoconf
BuildRequires:  autoconf-archive >= 2017.03.21
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-generators
BuildRequires:  python3-PyYAML
BuildRequires:  python3-base
BuildRequires:  python3-cryptography
BuildRequires:  python3-pyasn1-modules
BuildRequires:  python3-setuptools
BuildRequires:  python3-tpm2-pytss
BuildRequires:  tpm2.0-tools
BuildRequires:  pkgconfig(libcrypto) >= 1.0.2g
BuildRequires:  pkgconfig(p11-kit-1)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(tss2-esys) >= 2.0
BuildRequires:  pkgconfig(tss2-mu)
BuildRequires:  pkgconfig(tss2-rc)
BuildRequires:  pkgconfig(tss2-tctildr)
BuildRequires:  pkgconfig(yaml-0.1)
# Merge both subpackages
Provides:       libtpm2_pkcs11-0 = %{version}
Obsoletes:      libtpm2_pkcs11-0 < %{version}
Provides:       tpm2-pkcs11-devel = %{version}
Obsoletes:      tpm2-pkcs11-devel < %{version}
%{?python_enable_dependency_generator}

%description
tpm2-pkcs11 is a plugin shared library implementing the PKCS #11
Cryptographic Token Interface (Cryptoki) C API atop of TPM2 devices.

%dnl "make install" copies no .h files, a strong indicator that this project is
%dnl an (SLPP-exempt) plugin rather than a "normal" shared library.

%prep
%autosetup

%build
autoreconf -fiv
%configure --disable-static
%make_build
cd tools
%python_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
mkdir -p %{buildroot}%{_sysconfdir}/tpm2_pkcs11
cd tools
%python_install
%fdupes %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc docs/*
%dir %{_datadir}/p11-kit/modules
%dir %{_datadir}/p11-kit
%dir %{_libdir}/pkcs11
%{_datadir}/p11-kit/modules/tpm2_pkcs11.module
%{_sysconfdir}/tpm2_pkcs11
%{_bindir}/tpm2_ptool
%{python_sitelib}/tpm2_pkcs11
%{python_sitelib}/*.egg-info
%{_libdir}/pkcs11/libtpm2_pkcs11.so.%{so_ver}*
%{_libdir}/pkcs11/libtpm2_pkcs11.so
%{_libdir}/pkgconfig/tpm2-pkcs11.pc

%changelog
* Thu May 18 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Merge subpackages lib and devel into the main one
* Thu Feb 16 2023 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 1.9.0
  + Fixed
  * Fix autoconf invocation on a release tarball not being a git
    repo for VERSION. VERSION file now generated and packaged as
    part of the release tarball from the git version information.
  * Fix TPM2_PKCS11_OWNER_AUTH not being used when a persistent SRK
    is needed in the C_InitToken path.
  * During an upgrade of the database to version 4, the config key
    'persistent' is added instead of 'transient', causing KeyError
    when using the upgraded database.
  * Leave the original db on upgrade failure, a bug caused the
    original db to be unlinked not the upgraded db.
  * A bug prevented the use of CreateLoaded if the TPM supports the
    command.
  * A bug when creating keys through the PKCS11 interface (not
    tpm2-ptool), the attributes for CKA_ALLOWED_MECHANISMS were
    encoded as a hex string and not a sequence of ints within the
    YAML. Correcting this will trigger a db upgrade to 8
  + Added
  * Env varibale PKCS11_SQL_LOCK to allow setting a lock directory,
    eg for temprary directory so lock files do not persist across
    reboots.
* Fri Jul  8 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 1.8.0
  + Fixed
  * Fix GetRandom Memory Leak
  * Fix some spelling mistakes
  * Fix unit test test_parser
  * Fix importing of RSA private key through pkcs11 interface should
    fail.
  * Fix ECDSA signature length calculation.
  * Fix memory leak of tokens.
  * Fix suspicious sizeof usage in _str_padded_copy
  * Fix encoding errors when importing a certificate into the pkcs11
    store.
  * Fix try/finally scope issues in tpm2_ptool.
  * Fix, an OOB access in db upgrade path.
  * Fix ECDSA length calculation that was causing issues with Mutual
    TLS in Firefox and Chrome.
  + Changed
  * remove unused macro set_safe_rc
  + Added
  * Add support for OpenSSL 3. Note that calls through engine are no
    longer supported on OpenSSL3.
  * Add tpm2_ptool export commandlet for exporting token keys into
    PEM and TPM blob format.
- Add new dependencies to PyYAML, cryptography, pyasn1 and tpm2-pytss
* Sat Feb 26 2022 Callum Farmer <gmbr3@opensuse.org>
- Use hardlinks in %%fdupes for python files
* Wed Oct 20 2021 Callum Farmer <gmbr3@opensuse.org>
- Add keyring & use source verification
* Wed Oct 20 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Update to 1.7.0
  + DB Schema Change from 5 to 7.
  * Backup your DB before upgrading
  + Fixed compilation issues with GCC11.
  + Fixed errors on releases due to newer compilers from failing by
    only adding -Werror for non-release builds.
  + Fixed error message when the DB is too new in tpm2_ptool.
  + Added support for tpm2_ptool import with ssh-keygen format
    keys. Note: Requires cryptography >= 3.0.
  + Changed default long level from error to warning.
  + Added better error message for FAPI backend errors along with
    docs/FAPI.md document.
  + Changed tpm2_ptool make --algorithm optional.
  + Fixed error message of wrong attribute name on expected attribute
    check to be false.
  + Added support for ECDSA 256, 384 and 512.
  + Fixed a bug in the Python code DB upgrade path from 4 to 5 where
    it didn't add AES mode CTR to CKA_ALLOWED_MECHANISMS.
  + Added tpm2_ptool support for ECC key size 192.
  + Added support passwordless login for tokens, ie not setting
    CKF_LOGIN_REQUIRED.
  + Fixed Running integration tests when Java version has the -ea,
    like on Debian 11 and OpenJDK 17.
  + Added support for HMAC keys using tpm2_ptool and the C_Sign and
    C_Verify interfaces. The following interfaces in ptool have
    support:
  * addkey: previous working versions of tpm2-tools will support
    this.
  * link: previous working versions of tpm2-tools will support this.
  * import: requires tpm2-tools 5.2+ for support.
  + Fixed leaking of temp file descriptors in tpm2_ptool.
  + Fixed wrong free in tpm code, should use Esys_Free.
  + Fixed a space formatting issue in tpm2_ptool verify.
  + Fixed leaked file descriptor in tpm2_ptool.
  + Fixed a few suspicious sizeof usages in str_padded_copy
  + Fixed a memory leak of the token list on a failure condition in
    initialization.
* Sun Aug 22 2021 Jan Engelhardt <jengelh@inai.de>
- Use definite tense in %%description.
* Sat Aug 21 2021 Callum Farmer <gmbr3@opensuse.org>
- Build and install python tools
* Fri Aug 20 2021 Callum Farmer <gmbr3@opensuse.org>
- Clean spec file
- Use better source URL
- Split library
- Don't package .la files
- Create store directory
- Move devel library to devel subpackage
* Wed Sep  9 2020 Alexander Evseev <aevseev@gmail.com> - 1.4.0
- New upstream version - 1.4.0
* Mon Aug  3 2020 Alexander Evseev <aevseev@gmail.com> - 1.3.1
- First build. Version - 1.3.1
